//--------------------------------------------------------------
// File     : main.c
// Datum    : 08.05.2015
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F429
// Board    : STM32F429-Board von UB (Version 1.0)
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Hauptprogramm
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
// In Configuration diese Define hinzufgen :
// "STM32F429_439xx" , "__ASSEMBLY__" , "USE_STDPERIPH_DRIVER"
//--------------------------------------------------------------
// Beschreibung :
// LoLevel-Test vom eigenbau STM32F429-Board von UB (Version 1.0)
//
// test der USB-OTG-Buchse auf dem Board (CDC-Device)
// echo der empfangenen Daten
//
// Statusausgabe per COM-6 (3,3V UART) 115200 Baud
//--------------------------------------------------------------


#include "main.h"
#include "stm32_ub_usb_cdc.h"
#include "stm32_ub_uart.h"

int main(void)
{
  uint8_t status=99;
  char buf[APP_TX_BUF_SIZE]; // puffer fuer Datenempfang
  USB_CDC_RXSTATUS_t check=RX_EMPTY;


  SystemInit(); // Quarz Einstellungen aktivieren

  // init der uart
  UB_Uart_Init();

  // init der USB als CDC-Device
  UB_USB_CDC_Init();

  // powerOn string
  UB_Uart_SendString(COM6,"F429-Board",CRLF);
  UB_Uart_SendString(COM6,"USB-CDC-Device-Check",CRLF);

  while(1)
  {
    // Test ob USB-Verbindung zum PC besteht
    if(UB_USB_CDC_GetStatus()==USB_CDC_CONNECTED) {
      if(status!=1) {
        status=1;
        UB_Uart_SendString(COM6,"USB connected",CRLF);
      }
      // Ceck ob Daten per USB empfangen wurden
      check=UB_USB_CDC_ReceiveString(buf);
      if(check==USB_RX_READY) {
        UB_Uart_SendString(COM6,"USB Data received",CRLF);
        // wenn Daten empfangen wurden
        // als Echo wieder zurcksenden
        // (mit LineFeed+CarriageReturn)
        UB_USB_CDC_SendString("RX:[",USB_NONE);
        UB_USB_CDC_SendString(buf,USB_NONE);
        UB_USB_CDC_SendString("]",USB_LFCR);
      }
    }
    else {
      if(status!=0) {
        status=0;
        UB_Uart_SendString(COM6,"USB disconnected",CRLF);
      }
    }
  }
}

